# Generated by Django 2.2.6 on 2019-10-09 15:44

from django.conf import settings
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('tracker', '0067_auto_20191009_1451'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='messages',
            unique_together={('guid', 'theme', 'state', 'checksum', 'user', 'to_whom')},
        ),
    ]
